<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>ConfirmPassphraseDialog</name>
    <message>
        <source>Set Passphrase</source>
        <translation>Nustatyti slaptafrazę</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>Kai slaptafrazės nereikia, palikite lauką tuščią</translation>
    </message>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>&amp;Slaptafrazė:</translation>
    </message>
    <message>
        <source>&amp;Confirmation:</source>
        <translation>&amp;Pakartokite:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Grįžti</translation>
    </message>
    <message>
        <source>The confirmation passphrase does not match</source>
        <translation>Pakartota slaptafrazė nesutampa</translation>
    </message>
</context>
<context>
    <name>FileEncryptionDialog</name>
    <message>
        <source>File Encryption</source>
        <translation>Failų šifravimas</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komanda</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Pradėti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Failai</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formatas:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Naršyti...</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Išvesties failas:</translation>
    </message>
    <message>
        <source>Input file:</source>
        <translation>Įvesties failas:</translation>
    </message>
    <message>
        <source>EncryptPad format</source>
        <translation>EncryptPad formatas</translation>
    </message>
    <message>
        <source>EPD</source>
        <translation>EPD</translation>
    </message>
    <message>
        <source>OpenPGP</source>
        <translation>OpenPGP</translation>
    </message>
    <message>
        <source>GPG</source>
        <translation>GPG</translation>
    </message>
    <message>
        <source>OpenPGP Armor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ASC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key path</source>
        <translation>Rakto kelias</translation>
    </message>
    <message>
        <source>Key file path:</source>
        <translation>Rakto failo kelias:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>Slaptafrazė</translation>
    </message>
    <message>
        <source>Passphrase:</source>
        <translation>Slaptafrazė:</translation>
    </message>
    <message>
        <source>Confirmation:</source>
        <translation>Pakartokite:</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parametrai</translation>
    </message>
    <message>
        <source>Parameters...</source>
        <translation>Parametrai...</translation>
    </message>
    <message>
        <source>Encryption:</source>
        <translation>Šifravimas:</translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation>Šifruoti</translation>
    </message>
    <message>
        <source>Decrypt</source>
        <translation>Iššifruoti</translation>
    </message>
    <message>
        <source>SwitchDirection</source>
        <translation>SwitchDirection</translation>
    </message>
    <message>
        <source>IOChange</source>
        <translation>IOChange</translation>
    </message>
    <message>
        <source>Input File</source>
        <translation>Įvesties failas</translation>
    </message>
    <message>
        <source>Output File</source>
        <translation>Išvesties failas</translation>
    </message>
    <message>
        <source>EncryptPad</source>
        <translation>EncryptPad</translation>
    </message>
    <message>
        <source>Confirmation passphrase does not match.</source>
        <translation>Pakartota slaptafrazė nesutampa.</translation>
    </message>
    <message>
        <source>%1 does not exist.</source>
        <translation>%1 nėra.</translation>
    </message>
    <message>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 jau yra.
Ar norite jį pakeisti?</translation>
    </message>
    <message>
        <source>Cannot open the encryption key</source>
        <translation>Nepavyksta atverti šifravimo rakto</translation>
    </message>
    <message>
        <source>The encryption key is invalid</source>
        <translation>Šifravimo raktas yra neteisingas</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found.</source>
        <translation>Nepavyksta atsisiųsti šifravimo rakto. Nerastas CURL įrankis.</translation>
    </message>
    <message>
        <source>Cannot download the key. CURL returned non zero exit code</source>
        <translation>Nepavyksta atsisiųsti raktą. CURL grąžino nenulinį išėjimo kodą</translation>
    </message>
    <message>
        <source>Invalid passphrase for key file</source>
        <translation>Neteisinga rakto failo slaptafrazė</translation>
    </message>
    <message>
        <source>The job has been cancelled</source>
        <translation>Užduoties atsisakyta</translation>
    </message>
    <message>
        <source>File has been encrypted successfully.</source>
        <translation>Failas sėkmingai užšifruotas.</translation>
    </message>
    <message>
        <source>File has been decrypted successfully.</source>
        <translation>Failas sėkmingai iššifruotas.</translation>
    </message>
</context>
<context>
    <name>FileExtensions</name>
    <message>
        <source>ASCII-armored GnuPG (*.asc)</source>
        <translation>ASCII-šarvuotasis GnuPG (*.asc)</translation>
    </message>
    <message>
        <source>Plain Text (*.txt)</source>
        <translation>Grynasis tekstas (*.txt)</translation>
    </message>
    <message>
        <source>Encrypted Files (*.epd *.gpg *.asc);; Plain Text (*.txt)</source>
        <translation>Šifruoti failai (*.epd *.gpg *.asc);; Grynasis tekstas (*.txt)</translation>
    </message>
    <message>
        <source>Key (*.key)</source>
        <translation>Raktas (*.key)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Visi failai (*)</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation>Visi failai (*.*)</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <source>File Properties</source>
        <translation>Failo savybės</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <source>Iterations:</source>
        <translation>Iteracijų:</translation>
    </message>
    <message>
        <source>Triple DES</source>
        <comment>2</comment>
        <translation>Trigubas DES</translation>
    </message>
    <message>
        <source>CAST5</source>
        <comment>3</comment>
        <translation>CAST5</translation>
    </message>
    <message>
        <source>AES-128</source>
        <comment>7</comment>
        <translation>AES-128</translation>
    </message>
    <message>
        <source>AES-256 (recommended)</source>
        <comment>9</comment>
        <translation>AES-256 (rekomenduojama)</translation>
    </message>
    <message>
        <source>Compression:</source>
        <translation>Glaudinimas:</translation>
    </message>
    <message>
        <source>ZIP</source>
        <comment>1</comment>
        <translation>ZIP</translation>
    </message>
    <message>
        <source>ZLIB</source>
        <comment>2</comment>
        <translation>ZLIB</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <comment>2</comment>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-256 (recommended)</source>
        <comment>8</comment>
        <translation>SHA-256 (rekomenduojama)</translation>
    </message>
    <message>
        <source>Salt:</source>
        <translation>&quot;Salt&quot; reikšmė:</translation>
    </message>
    <message>
        <source>Hash:</source>
        <translation>Maiša:</translation>
    </message>
    <message>
        <source>FFFFFFFFFFFFFFFF</source>
        <translation>FFFFFFFFFFFFFFFF</translation>
    </message>
    <message>
        <source>PropertyChanged</source>
        <translation>PropertyChanged</translation>
    </message>
    <message>
        <source>AES-256 (recommended)</source>
        <translation>AES-256 (rekomenduojama)</translation>
    </message>
    <message>
        <source>Uncompressed</source>
        <translation>Nesuglaudintas</translation>
    </message>
</context>
<context>
    <name>FindAndReplace</name>
    <message>
        <source>Replace</source>
        <translation>Pakeisti</translation>
    </message>
    <message>
        <source>&amp;Replace with:</source>
        <translation>&amp;Kuo pakeisti:</translation>
    </message>
    <message>
        <source>&amp;Find:</source>
        <translation>&amp;Rasti:</translation>
    </message>
    <message>
        <source>Match case</source>
        <translation>Skirti raidžių dydį</translation>
    </message>
    <message>
        <source>Match whole word only</source>
        <translation>Atitikti tik visą žodį</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Rasti kitą</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Pakeisti visus</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Rasti</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>Ž&amp;emyn</translation>
    </message>
    <message>
        <source>Match whole &amp;word only</source>
        <translation>Atitikti tik &amp;visą žodį</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>A&amp;ukštyn</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>&amp;Skirti raidžių dydį</translation>
    </message>
    <message>
        <source>&amp;Find:</source>
        <translation>&amp;Rasti:</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Rasti &amp;kitą</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <source>425</source>
        <translation>425</translation>
    </message>
</context>
<context>
    <name>GetPassphraseDialog</name>
    <message>
        <source>Passphrase</source>
        <translation>Slaptafrazė</translation>
    </message>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>&amp;Slaptafrazė:</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>Kai slaptafrazės nereikia, palikite lauką tuščią</translation>
    </message>
</context>
<context>
    <name>GetPassphraseOrKeyDialog</name>
    <message>
        <source>Passphrase or Key File</source>
        <translation>Slaptafrazė ar rakto failas</translation>
    </message>
    <message>
        <source>Passphrase:</source>
        <translation>Slaptafrazė:</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Rakto failas:</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>Kai slaptafrazės nereikia, palikite lauką tuščią</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Pasirinkti rakto failą</translation>
    </message>
</context>
<context>
    <name>LoadSaveHandler</name>
    <message>
        <source>Passphrase for Key File</source>
        <translation>Rakto failo slaptafrazė</translation>
    </message>
    <message>
        <source>Cannot open the file because it does not exist</source>
        <translation>Nepavyksta atverti failo, nes jo nėra</translation>
    </message>
    <message>
        <source>GPG format does not support persistent key path.</source>
        <translation>GPG formatas nepalaiko pastovaus rakto kelio.</translation>
    </message>
    <message>
        <source>Do you want to disable it?</source>
        <translation>Ar norite jį išjungti?</translation>
    </message>
    <message>
        <source>GPG format does not support double protection by passphrase and key file.</source>
        <translation>GPG formatas nepalaiko dvigubos apsaugos slaptafraze ir rakto failu.</translation>
    </message>
    <message>
        <source>Use EPD format or disable either passphrase or key protection.</source>
        <translation>Naudokite EPD formatą arba išjunkite slaptafrazę, arba raktą.</translation>
    </message>
    <message>
        <source>Neither a key file nor passphrase is set. The file is going to be saved UNENCRYPTED.</source>
        <translation>Nėra nustatyti nei rakto failas, nei slaptafrazė. Failas bus įrašytas NEŠIFRUOTAI.</translation>
    </message>
    <message>
        <source>Neither a key file nor passphrase is set.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>ln: %1 of %2</source>
        <translation>Ties: %1 iš %2</translation>
    </message>
    <message>
        <source>chars: %1</source>
        <translation>simb.: %1</translation>
    </message>
    <message>
        <source>Passphrase not set</source>
        <translation>Slaptafrazė nenustatyta</translation>
    </message>
    <message>
        <source>Passphrase protected</source>
        <translation>Apsaugota slaptafraze</translation>
    </message>
    <message>
        <source>Cannot open &apos;%1&apos;</source>
        <translation>Nepavyksta atverti &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot open the encryption key</source>
        <translation>Nepavyksta atverti šifravimo raktą</translation>
    </message>
    <message>
        <source>The encryption key is invalid</source>
        <translation>Šifravimo raktas yra neteisingas</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found.</source>
        <translation>Nepavyksta atsisiųsti šifravimo rakto. Nerastas CURL įrankis.</translation>
    </message>
    <message>
        <source>Cannot download the key. CURL returned non zero exit code</source>
        <translation>Nepavyksta atsisiųsti raktą. CURL grąžino nenulinį išėjimo kodą</translation>
    </message>
    <message>
        <source>Cannot load the file</source>
        <translation>Nepavyksta įkelti failą</translation>
    </message>
    <message>
        <source>File loaded</source>
        <translation>Failas įkeltas</translation>
    </message>
    <message>
        <source>The file has been modified by another program. Do you want to reload it?</source>
        <translation>Failas buvo modifikuotas kitos programos. Ar norite jį įkelti iš naujo?</translation>
    </message>
    <message>
        <source>The file has been modified by another program. Do you want to reload it and lose the changes made in this application?</source>
        <translation>Failas buvo modifikuotas kitos programos. Ar norite jį įkelti iš naujo ir prarasti šioje programoje atliktus pakeitimus?</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Įrašyti failą kaip</translation>
    </message>
    <message>
        <source>Cannot create the repository directory in HOME</source>
        <translation>Nepavyksta sukurti saugyklos katalogo NAMŲ aplanke</translation>
    </message>
    <message>
        <source>Passphrase for Key File</source>
        <translation>Rakto failo slaptafrazė</translation>
    </message>
    <message>
        <source>You left the passphrase blank. The key file is going to be UNENCRYPTED. Do you want to continue?</source>
        <translation>Jūs palikote slaptafrazę tuščią. Rakto failas bus NEŠIFRUOTAS. Ar norite tęsti?</translation>
    </message>
    <message>
        <source>Cannot generate the key &apos;%1&apos; Check the path and permissions.</source>
        <translation>Nepavyksta generuoti raktą &quot;%1&quot;. Patikrinkite kelią ir leidimus.</translation>
    </message>
    <message>
        <source>Cannot generate key</source>
        <translation>Nepavyksta generuoti rakto</translation>
    </message>
    <message>
        <source>Do you want to use the generated key for this file?</source>
        <translation>Ar norite šiam failui naudoti sugeneruotą raktą?</translation>
    </message>
    <message>
        <source>About EncryptPad</source>
        <translation>Apie EncryptPad</translation>
    </message>
    <message>
        <source>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;A minimalist secure text editor and file encryptor that implements RFC 4880 Open PGP format: symmetrically encrypted, compressed and integrity protected. The editor can protect files with passphrases, key files or both.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU General Public License v2&lt;br/&gt;&lt;br/&gt;</source>
        <oldsource>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;Minimalist secure text editor and binary encryptor that implements RFC 4880 Open PGP format: symmetrically encrypted, compressed and integrity protected. The editor can protect files with passphrases, key files or both.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU General Public License v2&lt;br/&gt;&lt;br/&gt;</oldsource>
        <translation>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;Minimalistinis saugus tekstų redaktorius ir failų šifravimo įrankis, įgyvendinantis RFC 4880 Open PGP formatą: simetriškai šifruotą, glaudintą ir apsaugotą vientisumu. Redaktorius gali apsaugoti failus slaptafrazėmis, rakto failais arba abiem.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU Bendroji viešoji licencija v2&lt;br/&gt;&lt;br/&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;OpenPGP implementation.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;Simplified BSD License&lt;br/&gt;&lt;br/&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;OpenPGP įgyvendinimas.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;Supaprastinta BSD licencija&lt;br/&gt;&lt;br/&gt;</translation>
    </message>
    <message>
        <source>Do you want to apply the modified default file properties to this file?</source>
        <translation>Ar norite pritaikyti modifikuotas numatytąsias failo savybes šiam failui?</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>Create a new file</source>
        <translation>Sukurti naują failą</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Atverti...</translation>
    </message>
    <message>
        <source>Open an existing file</source>
        <translation>Atverti esamą failą</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Į&amp;rašyti</translation>
    </message>
    <message>
        <source>Save the document to disk</source>
        <translation>Įrašyti dokumentą į diską</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Įrašyti &amp;kaip...</translation>
    </message>
    <message>
        <source>Save the document under a new name</source>
        <translation>Įrašyti dokumentą nauju pavadinimu</translation>
    </message>
    <message>
        <source>File &amp;Properties...</source>
        <translation>Failo &amp;savybės...</translation>
    </message>
    <message>
        <source>Set file properties</source>
        <translation>Nustatyti failo savybes</translation>
    </message>
    <message>
        <source>&amp;Close and Reset</source>
        <translation>&amp;Užverti ir atstatyti</translation>
    </message>
    <message>
        <source>Close and reset security settings</source>
        <translation>Užverti ir atstatyti saugumo nustatymus</translation>
    </message>
    <message>
        <source>Generate Key...</source>
        <translation>Generuoti raktą...</translation>
    </message>
    <message>
        <source>Generate a new key file</source>
        <translation>Generuoti naują rakto failą</translation>
    </message>
    <message>
        <source>Set &amp;Passphrase...</source>
        <translation>Nustatyti slapta&amp;frazę...</translation>
    </message>
    <message>
        <source>Set passphrase for encryption and decryption</source>
        <translation>Nustatyti slapafrazę, skirtą šifravimui ir iššifravimui</translation>
    </message>
    <message>
        <source>Set &amp;Encryption Key...</source>
        <translation>Nustatyti š&amp;ifravimo raktą...</translation>
    </message>
    <message>
        <source>Set encryption key file</source>
        <translation>Nustatyti šifravimo rakto failą</translation>
    </message>
    <message>
        <source>Clear &amp;Encryption Key</source>
        <translation>Išvalyti šifr&amp;avimo raktą</translation>
    </message>
    <message>
        <source>Clear encryption key file. Passphrase only (if set).</source>
        <translation>Išvalyti šifravimo rakto failą. Tik slaptafrazė (jei nustatyta).</translation>
    </message>
    <message>
        <source>&amp;Clear Passphrase</source>
        <translation>Iš&amp;valyti slaptafrazę</translation>
    </message>
    <message>
        <source>Save without passphrase protected encryption. Encryption with file key only (if enabled).</source>
        <translation>Įrašyti be slaptafraze apsaugoto šifravimo. Šifravimas tik su rakto failu (jei įjungta).</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Iš&amp;eiti</translation>
    </message>
    <message>
        <source>Exit the application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Grąžinti</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Iš&amp;kirpti</translation>
    </message>
    <message>
        <source>Cut the current selection&apos;s contents to the clipboard</source>
        <translation>Iškirpti dabartinio žymėjimo turinį į iškarpinę</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopijuoti</translation>
    </message>
    <message>
        <source>Copy the current selection&apos;s contents to the clipboard</source>
        <translation>Kopijuoti dabartinio žymėjimo turinį į iškarpinę</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Į&amp;dėti</translation>
    </message>
    <message>
        <source>Paste the clipboard&apos;s contents into the current selection</source>
        <translation>Įdėti iškarpinės turinį į dabartinį žymėjimą</translation>
    </message>
    <message>
        <source>&amp;Select All</source>
        <translation>Ž&amp;ymėti viską</translation>
    </message>
    <message>
        <source>Select all text</source>
        <translation>Žymėti visą tekstą</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Rasti...</translation>
    </message>
    <message>
        <source>Find in text</source>
        <translation>Rasti tekste</translation>
    </message>
    <message>
        <source>&amp;Go to...</source>
        <translation>&amp;Pereiti į...</translation>
    </message>
    <message>
        <source>Go to</source>
        <translation>Pereiti į</translation>
    </message>
    <message>
        <source>&amp;Generate Passphrase...</source>
        <translation>&amp;Generuoti slaptafrazę...</translation>
    </message>
    <message>
        <source>Generate passphrase</source>
        <translation>Generuoti slaptafrazę</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Pakeisti...</translation>
    </message>
    <message>
        <source>Find and replace text</source>
        <translation>Rasti ir pakeisti tekstą</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Tik skaityti</translation>
    </message>
    <message>
        <source>Enable Read Only mode</source>
        <translation>Įjungti tik skaitymo veikseną</translation>
    </message>
    <message>
        <source>Word Wrap</source>
        <translation>Teksto skaidymas į eilutes</translation>
    </message>
    <message>
        <source>Enable Word Wrap</source>
        <translation>Įjungti teksto skaidymą į eilutes</translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation>&amp;Didinti</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Didinti</translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation>&amp;Mažinti</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Mažinti</translation>
    </message>
    <message>
        <source>&amp;Reset Zoom</source>
        <translation>&amp;Atstatyti mastelį</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Atstatyti mastelį</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Apie...</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Rodyti langelį apie programą</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Show the Qt library&apos;s About box</source>
        <translation>Rodyti langelį apie Qt biblioteką</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nuostatos...</translation>
    </message>
    <message>
        <source>Application preferences</source>
        <translation>Programos nuostatos</translation>
    </message>
    <message>
        <source>File Encryption...</source>
        <translation>Failų šifravimas...</translation>
    </message>
    <message>
        <source>File encryption</source>
        <translation>Failų šifravimas</translation>
    </message>
    <message>
        <source>Windows EOL</source>
        <translation>Windows eilutės pabaiga</translation>
    </message>
    <message>
        <source>&quot;Windows&quot; end of line: CR+LF</source>
        <translation>&quot;Windows&quot; eilutės pabaiga: CR+LF</translation>
    </message>
    <message>
        <source>End of file reached. Started from the top.</source>
        <translation>Prieita prie failo pabaigos. Pradėta nuo viršaus.</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Tekstas nerastas.</translation>
    </message>
    <message>
        <source>Text found.</source>
        <translation>Tekstas rastas.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Taisa</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Rodinys</translation>
    </message>
    <message>
        <source>En&amp;cryption</source>
        <translation>Šifra&amp;vimas</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Nu&amp;statymai</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Failas</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Taisa</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifravimas</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodinys</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pasiruošę</translation>
    </message>
    <message>
        <source>The document has been modified.</source>
        <translation>Šis dokumentas buvo modifikuotas.</translation>
    </message>
    <message>
        <source>Do you want to save your changes?</source>
        <translation>Ar norite įrašyti pakeitimus?</translation>
    </message>
    <message>
        <source>Cannot save &apos;%1&apos;</source>
        <translation>Nepavyksta įrašyti &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot open the specified encryption key</source>
        <translation>Nepavyksta atverti nurodytą šifravimo raktą</translation>
    </message>
    <message>
        <source>The specified encryption key is invalid</source>
        <translation>Nurodytas šifravimo raktas yra neteisingas</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found</source>
        <translation>Nepavyksta atsisiųsti šifravimo rakto. Nerastas CURL įrankis</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL returned non zero exit code</source>
        <translation>Nepavyksta atsisiųsti šifravimo raktą. CURL grąžino nenulinį išėjimo kodą</translation>
    </message>
    <message>
        <source>Unknown encryption error</source>
        <translation>Nežinoma šifravimo klaida</translation>
    </message>
    <message>
        <source>Cannot create bak file</source>
        <translation>Nepavyksta sukurti bak failą</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nežinoma klaida</translation>
    </message>
    <message>
        <source>Cannot save file</source>
        <translation>Nepavyksta įrašyti failą</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Failas įrašytas</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Eilutės numeris:</translation>
    </message>
    <message>
        <source>Maximum zoom</source>
        <translation>Didžiausias mastelis</translation>
    </message>
    <message>
        <source>Font size: %1</source>
        <translation>Šrifto dydis: %1</translation>
    </message>
    <message>
        <source>Minimum zoom</source>
        <translation>Mažiausias mastelis</translation>
    </message>
    <message>
        <source>Font size: </source>
        <translation>Šrifto dydis: </translation>
    </message>
    <message>
        <source>untitled</source>
        <translation>be pavadinimo</translation>
    </message>
    <message>
        <source>Key protected</source>
        <translation>Apsaugota raktu</translation>
    </message>
    <message>
        <source>Key not set</source>
        <translation>Raktas nenustatytas</translation>
    </message>
    <message>
        <source>persistent</source>
        <translation>pastovus</translation>
    </message>
    <message>
        <source>options:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--lang&lt;/b&gt; - to enforce the language for the GUI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--log-file&lt;/b&gt; - specify the log file for diagnostics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--log-severity&lt;/b&gt; - log severity can be one of the following list: none, fatal, error, warning, info, debug, verbose</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Command Line Interface</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>encryptpad[.exe] [options] [file]</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NewKeyDialog</name>
    <message>
        <source>Generate Key</source>
        <translation>Generuoti raktą</translation>
    </message>
    <message>
        <source>&amp;Key path</source>
        <translation>&amp;Rakto kelias</translation>
    </message>
    <message>
        <source>Key in &amp;repository</source>
        <translation>Raktas &amp;saugykloje</translation>
    </message>
    <message>
        <source>Key path</source>
        <translation>Rakto kelias</translation>
    </message>
    <message>
        <source>The repository is &lt;b&gt;.encryptpad&lt;/b&gt; directory in the user&apos;s profile (&lt;b&gt;encryptpad_repository&lt;/b&gt; in portable mode).</source>
        <translation>Saugykla yra &lt;b&gt;.encryptpad&lt;/b&gt; katalogas naudotojo profilyje (&lt;b&gt;encryptpad_repository&lt;/b&gt; perkeliamoje veiksenoje).</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Naršyti...</translation>
    </message>
    <message>
        <source>Key name in the repository</source>
        <translation>Rakto pavadinimas saugykloje</translation>
    </message>
    <message>
        <source>Save New Key To</source>
        <translation>Įrašyti naują raktą į</translation>
    </message>
    <message>
        <source>Invalid characters in the key name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PassphraseGenerationDialog</name>
    <message>
        <source>Generate Passphrase</source>
        <translation>Generuoti slaptafrazę</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>Pasirinktiniai:</translation>
    </message>
    <message>
        <source>Lowercase a-z</source>
        <translation>Mažosios a-z</translation>
    </message>
    <message>
        <source>Numbers 0-9</source>
        <translation>Skaitmenys 0-9</translation>
    </message>
    <message>
        <source>Symbols:</source>
        <translation>Simboliai:</translation>
    </message>
    <message>
        <source>` ~ ! @ # $ % ^ &amp; * ( ) _ - + = { } [ ]  | : ; &quot; &apos; &lt; &gt; , . ? /</source>
        <translation>` ~ ! @ # $ % ^ &amp; * ( ) _ - + = { } [ ]  | : ; &quot; &apos; &lt; &gt; , . ? /</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Pasirinktinis</translation>
    </message>
    <message>
        <source>Uppercase A-Z</source>
        <translation>Didžiosios A-Z</translation>
    </message>
    <message>
        <source>&amp;Regenerate</source>
        <translation>Gene&amp;ruoti iš naujo</translation>
    </message>
    <message>
        <source>Insert &amp;all</source>
        <translation>Įterpti &amp;visus</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>&amp;Ilgis:</translation>
    </message>
    <message>
        <source>Select &amp;passphrase:</source>
        <translation>Pasirinkite sla&amp;ptafrazę:</translation>
    </message>
    <message>
        <source>Limit group occurrence (1 to max chars)</source>
        <translation>Riboti grupės pasitaikymą (nuo 1 iki maks. simb.)</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupės</translation>
    </message>
    <message>
        <source>Regenerate</source>
        <translation>Generuoti iš naujo</translation>
    </message>
    <message>
        <source>7 passphrases</source>
        <translation>7 slaptafrazės</translation>
    </message>
    <message>
        <source>15 passphrases</source>
        <translation>15 slaptafrazių</translation>
    </message>
    <message>
        <source>25 passphrases</source>
        <translation>25 slaptafrazės</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <source>Libcurl command line parameters</source>
        <translation>Libcurl komandų eilutės parametrai</translation>
    </message>
    <message>
        <source>Parameters:</source>
        <translation>Parametrai:</translation>
    </message>
    <message>
        <source>Key file encryption properties:</source>
        <translation>Rakto failo šifravimo savybės:</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Šriftas:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Naršyti...</translation>
    </message>
    <message>
        <source>Create .bak files</source>
        <translation>Sukurti .bak failus</translation>
    </message>
    <message>
        <source>[example: Monospace (Size: 12)]</source>
        <translation>[example: Monospace (Size: 12)]</translation>
    </message>
    <message>
        <source>Save last used directory</source>
        <translation>Įrašyti paskutinį naudotą katalogą</translation>
    </message>
    <message>
        <source>Word wrap</source>
        <translation>Teksto skaidymas į eilutes</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Taisyti...</translation>
    </message>
    <message>
        <source>Libcurl path:</source>
        <translation>Libcurl kelias:</translation>
    </message>
    <message>
        <source>Recent files:</source>
        <translation>Paskiausiai naudoti failai:</translation>
    </message>
    <message>
        <source>Default file properties:</source>
        <translation>Numatytosios failo savybės:</translation>
    </message>
    <message>
        <source>This controls how many times you can save without entering a passphrase</source>
        <translation>Tai valdo kiek kartų galite įrašyti, neįvesdami slaptafrazės</translation>
    </message>
    <message>
        <source>S2K derivations from a passphrase:</source>
        <oldsource>Passphrase to key results pool size:</oldsource>
        <translation>S2K išvedimų iš slaptafrazės:</translation>
    </message>
    <message>
        <source>Key file random sequence length (bytes):</source>
        <translation>Rakto failo atsitiktinės sekos ilgis (baitais):</translation>
    </message>
    <message>
        <source>Enable FakeVim (restart required)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <source>Display line numbers</source>
        <translation>Rodyti eilučių numerius</translation>
    </message>
    <message>
        <source>&quot;Windows&quot; end of line: CR+LF</source>
        <translation>&quot;Windows&quot; eilutės pabaiga: CR+LF</translation>
    </message>
    <message>
        <source>Tab size:</source>
        <translation>Tab dydis:</translation>
    </message>
    <message>
        <source>Retain last used directory between EncryptPad sessions</source>
        <translation>Išlaikyti paskutinį naudotą katalogą tarp EncryptPad seansų</translation>
    </message>
    <message>
        <source>Path to libCURL executable</source>
        <translation>Kelias į libCURL vykdomąjį</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Šriftas...</translation>
    </message>
    <message>
        <source>(Size: </source>
        <translation>(Dydis: </translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Pasirinkti šriftą</translation>
    </message>
    <message>
        <source>Path to Libcurl</source>
        <translation>Kelias į Libcurl</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
</context>
<context>
    <name>SetKeyDialog</name>
    <message>
        <source>Set Encryption Key</source>
        <translation>Nustatyti šifravimo raktą</translation>
    </message>
    <message>
        <source>Key &amp;repository:</source>
        <translation>Rakto &amp;saugykla:</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>&amp;Naršyti...</translation>
    </message>
    <message>
        <source>&amp;Key file path:</source>
        <translation>&amp;Rakto failo kelias:</translation>
    </message>
    <message>
        <source>&amp;Persistent key location in the encrypted file</source>
        <translation>&amp;Pastovaus rakto vietą šifruotame faile</translation>
    </message>
    <message>
        <source>The repository is &lt;b&gt;.encryptpad&lt;/b&gt; directory in the user&apos;s profile (&lt;b&gt;encryptpad_repository&lt;/b&gt; in portable mode). Select a key or specify a file name without path for the repository keys.</source>
        <translation>Saugykla yra &lt;b&gt;.encryptpad&lt;/b&gt; katalogas naudotojo profilyje (&lt;b&gt;encryptpad_repository&lt;/b&gt; perkeliamoje veiksenoje). Pasirinkite raktą arba saugyklos raktams nurodykite failo pavadinimą be kelio.</translation>
    </message>
    <message>
        <source>Specify encryption key location</source>
        <translation>Nurodyti šifravimo rakto vietą</translation>
    </message>
</context>
<context>
    <name>SetPassphraseDialog</name>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>&amp;Slaptafrazė:</translation>
    </message>
    <message>
        <source>&amp;Confirmation:</source>
        <translation>&amp;Pakartokite:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Gerai</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Set Passphrase</source>
        <translation>Nustatyti slaptafrazę</translation>
    </message>
    <message>
        <source>The confirmation passphrase does not match</source>
        <translation>Pakartota slaptafrazė nesutampa</translation>
    </message>
</context>
</TS>